
from pyqweather import QWeatherRequestBase, QWeatherResponseBase

class HistoricalWeatherRequest(QWeatherRequestBase):
  
  _PATH = '/historical/weather'
  
  def __init__(self, **kwargs):
    super().__init__(**kwargs)
    self.location = self.get_arg('location', kwargs, required=True)
    self.date = self.get_arg('date', kwargs, required=True)
    self.lang = self.get_arg('lang', kwargs)
    self.unit = self.get_arg('unit', kwargs)
    
    
  def __str__(self) -> str:
    return f'location={self.location}'
  

class HistoricalWeatherResponse(QWeatherResponseBase):
  
  def __init__(self, **kwargs):
    super().__init__(**kwargs)
    self.fxLink = self.get_arg('fxLink', kwargs, None)
    self.weatherDaily= self.get_arg('weatherDaily', kwargs, None)
    self.weatherHourly:list[any] = self.get_arg('weatherHourly', kwargs, [])
    



from pyqweather import QWeatherRequestBase, QWeatherResponseBase

class Minutely5mRequest(QWeatherRequestBase):
  
  _PATH = '/minutely/5m'
  
  def __init__(self, **kwargs):
    super().__init__(**kwargs)
    self.location = self.get_arg('location', kwargs, required=True)
    self.lang = self.get_arg('lang', kwargs)
    
    
  def __str__(self) -> str:
    return f'location={self.location}'
  

class Minutely5mResponse(QWeatherResponseBase):
  
  def __init__(self, **kwargs):
    super().__init__(**kwargs)
    self.updateTime = self.get_arg('updateTime', kwargs, None)
    self.fxLink = self.get_arg('fxLink', kwargs, None)
    self.minutely:list[any] = self.get_arg('minutely', kwargs, [])
    self.summary = self.get_arg('summary', kwargs, None)
    



from pyqweather import QWeatherRequestBase, QWeatherResponseBase

class CityLookupRequest(QWeatherRequestBase):
  
  _PATH = '/city/lookup'
  
  def __init__(self, **kwargs):
    super().__init__(**kwargs)
    self.location = self.get_arg('location', kwargs, required=True)
    self.adm = self.get_arg('adm', kwargs)
    self.range = self.get_arg('range', kwargs)
    self.number = self.get_arg('number', kwargs)
    self.lang = self.get_arg('lang', kwargs)
    
    
  def __str__(self) -> str:
    return f'location={self.location}'
  


class CityLookupResponse(QWeatherResponseBase):
  
  def __init__(self, **kwargs):
    super().__init__(**kwargs)
    self.location:list[any] = self.get_arg('location', kwargs, [])
    